diff src/plugin.h @ 10447:6feef0a9098a

[gaim-migrate @ 11712] A few minor improvements and some documentation updates. Conscious evolution in the back of your mind... committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Wed, 29 Dec 2004 21:53:59 +0000
parents fae50349fd42
children 6a20307ef8dc
line wrap: on
line diff
--- a/src/plugin.h	Wed Dec 29 20:01:48 2004 +0000
+++ b/src/plugin.h	Wed Dec 29 21:53:59 2004 +0000
@@ -224,8 +224,14 @@
  * Registers a plugin and prepares it for loading.
  *
  * This shouldn't be called by anything but the internal module code.
+ * Plugins should use the GAIM_INIT_PLUGIN() macro to register themselves
+ * with the core.
  *
  * @param plugin The plugin to register.
+ *
+ * @return @c TRUE if the plugin was registered successfully.  Otherwise
+ *         @c FALSE is returned (this happens if the plugin does not contain
+ *         the necessary information).
  */
 gboolean gaim_plugin_register(GaimPlugin *plugin);
 
@@ -359,12 +365,11 @@
 /*@{*/
 
 /**
  * Sets the search paths for plugins.
  *
  * @param count The number of search paths.
  * @param paths The search paths.
  */
-void gaim_plugins_set_search_paths(size_t count, char **paths);
+void gaim_plugins_add_search_path(const char *path);
 
 /**
  * Unloads all loaded plugins.
@@ -359,12 +365,11 @@
 
 /**
- * Sets the search paths for plugins.
+ * Add a new directory to search for plugins
  *
@@ -359,12 +365,11 @@
  *
- * @param count The number of search paths.
- * @param paths The search paths.
+ * @param paths The new search path.
  */